@@ -174,7 +174,7 @@ static ComputerModernShaper::PlainChar cmmMap[] =
     { 0x0000, 0x00 }
   };
 
-static Char8 cmmTTFMap[] =
+static UChar8 cmmTTFMap[] =
   {
     /* 0x00 */ 0xa1, // Gamma
     /* 0x01 */ 0xa2, // Delta
@@ -439,7 +439,7 @@ static ComputerModernShaper::PlainChar cmrMap[] =
     { 0x0000, 0x00 }
   };
 
-static Char8 cmrTTFMap[] =
+static UChar8 cmrTTFMap[] =
   {
     /* 0x00 */ 0xa1, // Gamma
     /* 0x01 */ 0xa2, // Delta
@@ -704,7 +704,7 @@ static ComputerModernShaper::PlainChar cmsMap[] =
     { 0x0000, 0x00 }
   };
 
-static Char8 cmsTTFMap[] =
+static UChar8 cmsTTFMap[] =
   {
     /* 0x00 */ 0xa1, // minus
     /* 0x01 */ 0xa2, // periodcentered
@@ -847,8 +847,8 @@ static ComputerModernShaper::HStretchyChar hMap[] =
     { 0x21aa, {NIL, 0x00}, {CMM, 0x2C}, {CMS, 0x00}, {CMS, 0x21} },
     { 0x21bc, {CMM, 0x28}, {NIL, 0x00}, {CMS, 0x00}, {NIL, 0x00} },
     { 0x21bd, {CMM, 0x29}, {NIL, 0x00}, {CMS, 0x00}, {NIL, 0x00} },
-    { 0x21c0, {CMS, 0x2A}, {NIL, 0x00}, {CMS, 0x00}, {NIL, 0x00} },
-    { 0x21c1, {CMS, 0x2B}, {NIL, 0x00}, {CMS, 0x00}, {NIL, 0x00} },
+    { 0x21c0, {CMM, 0x2A}, {NIL, 0x00}, {CMS, 0x00}, {NIL, 0x00} },
+    { 0x21c1, {CMM, 0x2B}, {NIL, 0x00}, {CMS, 0x00}, {NIL, 0x00} },
     { 0x21d0, {CMS, 0x28}, {CMS, 0x28}, {NIL, 0x00}, {NIL, 0x00} },
     { 0x21d4, {CMS, 0x2C}, {CMS, 0x28}, {NIL, 0x00}, {CMS, 0x29} },
     { 0x21d2, {CMS, 0x29}, {NIL, 0x00}, {NIL, 0x00}, {CMS, 0x29} },
@@ -911,7 +911,7 @@ static ComputerModernShaper::HBigChar hbMap[] =
 #define OVER_BRACE_INDEX OVER_BRACE
 #define UNDER_BRACE_INDEX UNDER_BRACE
 
-static Char8 cmexTTFMap[] =
+static UChar8 cmexTTFMap[] =
   {
     /* 0x00 */ 0xa1, // parenleftbig
     /* 0x01 */ 0xa2, // parenrightbig
@@ -1061,7 +1061,7 @@ static FontDesc variantDesc[] =
     { MONOSPACE_VARIANT, ComputerModernFamily::FN_CMTT }
   };
 
-inline Char8
+inline UChar8
 makeFontId(ComputerModernFamily::FontEncId id, MathVariant variant = NORMAL_VARIANT)
 {
   assert(ComputerModernFamily::validFontEncId(id));
@@ -1070,17 +1070,17 @@ makeFontId(ComputerModernFamily::FontEncId id, MathVariant variant = NORMAL_VARI
 }
 
 inline ComputerModernFamily::FontEncId
-encIdOfFontId(Char8 id)
+encIdOfFontId(UChar8 id)
 { return ComputerModernFamily::FontEncId(id & 0x0f); }
 
 inline MathVariant
-variantOfFontId(Char8 id)
+variantOfFontId(UChar8 id)
 { return MathVariant((id >> 4) + NORMAL_VARIANT); }
 
-Char8
-ComputerModernShaper::toTTFGlyphIndex(ComputerModernFamily::FontEncId name, Char8 index)
+UChar8
+ComputerModernShaper::toTTFGlyphIndex(ComputerModernFamily::FontEncId name, UChar8 index)
 {
-  Char8* map = 0;
+  UChar8* map = 0;
   switch (name)
     {
     case ComputerModernFamily::FE_CMR:
@@ -1149,14 +1149,23 @@ ComputerModernShaper::registerShaper(const SmartPtr<ShaperManager>& sm, unsigned
 
   for (unsigned i = 0; cmmMap[i].ch; i++)
     {
-      const Char32 ch = mapMathVariant(ITALIC_VARIANT, cmmMap[i].ch);
-      const Char32 vch = mapMathVariant(BOLD_ITALIC_VARIANT, ch);
-
+      const Char32 ch = cmmMap[i].ch;
+      const Char32 ch1 = mapMathVariant(ITALIC_VARIANT, ch);
       if (family->fontEnabled(ComputerModernFamily::FN_CMMI))
-	sm->registerChar(ch, GlyphSpec(shaperId, makeFontId(ComputerModernFamily::FE_CMMI, ITALIC_VARIANT), cmmMap[i].index));
+	{
+	  if (ch1 != ch)
+	    sm->registerChar(ch1, GlyphSpec(shaperId, makeFontId(ComputerModernFamily::FE_CMMI, ITALIC_VARIANT), cmmMap[i].index));
+	  else
+	    sm->registerChar(ch, GlyphSpec(shaperId, makeFontId(ComputerModernFamily::FE_CMMI, NORMAL_VARIANT), cmmMap[i].index));
+	}
 
-      if (family->fontEnabled(ComputerModernFamily::FN_CMMIB) && vch != ch)
-	sm->registerChar(vch, GlyphSpec(shaperId, makeFontId(ComputerModernFamily::FE_CMMI, BOLD_ITALIC_VARIANT), cmmMap[i].index));
+      const Char32 ch2 = mapMathVariant(BOLD_VARIANT, ch);
+      if (ch2 != ch && family->fontEnabled(ComputerModernFamily::FN_CMMIB))
+	sm->registerChar(ch2, GlyphSpec(shaperId, makeFontId(ComputerModernFamily::FE_CMMI, BOLD_VARIANT), cmmMap[i].index));
+
+      const Char32 ch3 = mapMathVariant(BOLD_ITALIC_VARIANT, ch);
+      if (ch3 != ch && ch3 != ch && family->fontEnabled(ComputerModernFamily::FN_CMMIB))
+	sm->registerChar(ch3, GlyphSpec(shaperId, makeFontId(ComputerModernFamily::FE_CMMI, BOLD_ITALIC_VARIANT), cmmMap[i].index));
     }
 
   for (unsigned i = 0; cmsMap[i].ch; i++)
@@ -1380,7 +1389,7 @@ ComputerModernShaper::getGlyphArea(MathVariant variant, const GlyphIndex& glyph,
 }
 
 AreaRef
-ComputerModernShaper::getGlyphArea(MathVariant variant, ComputerModernFamily::FontEncId encId, Char8 index, const scaled& size) const
+ComputerModernShaper::getGlyphArea(MathVariant variant, ComputerModernFamily::FontEncId encId, UChar8 index, const scaled& size) const
 {
   scaled finalSize = size;
   ComputerModernFamily::FontSizeId designSize;
