@@ -22,7 +22,6 @@
 
 #include <config.h>
 
-#include "View.hh"
 #include "BoxMLElement.hh"
 #include "BoxMLNamespaceContext.hh"
 
@@ -32,7 +31,10 @@ BoxMLElement::BoxMLElement(const SmartPtr<BoxMLNamespaceContext>& context) : Ele
 BoxMLElement::~BoxMLElement()
 { }
 
-scaled
-BoxMLElement::getStep() const
-{ return scaled::zero(); }
+void
+BoxMLElement::setMaxArea(const AreaRef& area)
+{ maxArea = area; }
 
+AreaRef
+BoxMLElement::getMaxArea() const
+{ return maxArea ? maxArea : getArea(); }
